@@ -1,4 +1,4 @@
-# Copyright 2004-2015 Tom Rothamel <pytom@bishoujo.us>
+# Copyright 2004-2016 Tom Rothamel <pytom@bishoujo.us>
 #
 # Permission is hereby granted, free of charge, to any person
 # obtaining a copy of this software and associated documentation files
@@ -22,6 +22,7 @@
 # This file ensures that renpy packages will be imported in the right
 # order.
 
+from __future__ import print_function
 import sys
 import os
 import copy
@@ -40,10 +41,10 @@ except ImportError:
     vc_version = 0
 
 # The tuple giving the version number.
-version_tuple = (6, 99, 8, vc_version)
+version_tuple = (6, 99, 12, 2, vc_version)
 
 # The name of this version.
-version_name = "Here's to the crazy ones."
+version_name = "We get the job done."
 
 # A string giving the version number only (7.0.1.123).
 version_only = ".".join(str(i) for i in version_tuple)
@@ -72,6 +73,7 @@ ios = False
 
 import platform
 
+
 def get_windows_version():
     """
     When called on windows, returns the windows version.
@@ -122,6 +124,9 @@ else:
 # A flag that's true if we're on a smartphone or tablet-like platform.
 mobile = android or ios
 
+# A flag that's set to true if the game directory is bundled inside a mac app.
+macapp = False
+
 
 ################################################################################
 # Backup Data for Reload
@@ -150,7 +155,15 @@ backup_blacklist = {
     "renpy.display.pgrender",
     "renpy.display.scale",
     "renpy.display.presplash",
+    "renpy.display.test",
     "renpy.text.ftfont",
+    "renpy.test",
+    "renpy.test.testast",
+    "renpy.test.testexecution",
+    "renpy.test.testkey",
+    "renpy.test.testmouse",
+    "renpy.test.testparser",
+    "renpycoverage",
     }
 
 type_blacklist = (
@@ -175,6 +188,7 @@ name_blacklist = {
     "renpy.display.screen.cprof",
     }
 
+
 class Backup():
     """
     This represents a backup of all of the fields in the python modules
@@ -216,7 +230,10 @@ class Backup():
         Makes a backup of `mod`, which must be a Python module.
         """
 
-        name = mod.__name__
+        try:
+            name = mod.__name__
+        except:
+            return
 
         if not name.startswith("renpy"):
             return
@@ -250,8 +267,8 @@ class Backup():
             try:
                 cPickle.dumps(v, cPickle.HIGHEST_PROTOCOL)
             except:
-                print "Cannot pickle", name + "." + k, "=", repr(v)
-                print "Reduce Ex is:", repr(v.__reduce_ex__(cPickle.HIGHEST_PROTOCOL))
+                print("Cannot pickle", name + "." + k, "=", repr(v))
+                print("Reduce Ex is:", repr(v.__reduce_ex__(cPickle.HIGHEST_PROTOCOL)))
 
     def restore(self):
         """
@@ -268,7 +285,6 @@ class Backup():
             for name in set(modvars.keys()) - names:
                 del modvars[name]
 
-
         objects = cPickle.loads(self.objects_pickle)
 
         for k, v in self.variables.iteritems():
@@ -282,6 +298,7 @@ backup = None
 # Import
 ################################################################################
 
+
 def update_path(package):
     """
     Update the __path__ of package, to import binary modules from a libexec
@@ -299,16 +316,17 @@ def update_path(package):
     libexec = os.path.dirname(encodings.__path__[0])
     package.__path__.append(os.path.join(libexec, *name))
 
+
 def import_all():
 
     # Note: If we add a new update_path, we have to add an equivalent
     # hook in the renpython hooks dir.
 
-    import renpy # @UnresolvedImport
+    import renpy  # @UnresolvedImport
 
     update_path(renpy)
 
-    import renpy.arguments # @UnresolvedImport
+    import renpy.arguments  # @UnresolvedImport
 
     import renpy.log
 
@@ -340,7 +358,7 @@ def import_all():
     import renpy.script
     import renpy.statements
 
-    import renpy.styledata # @UnresolvedImport
+    import renpy.styledata  # @UnresolvedImport
     update_path(renpy.styledata)
 
     import renpy.style
@@ -350,8 +368,13 @@ def import_all():
 
     import renpy.substitutions
     import renpy.translation
+    import renpy.translation.scanstrings
+    import renpy.translation.generation
+    import renpy.translation.dialogue
+    import renpy.translation.extract
+    import renpy.translation.merge
 
-    import renpy.display # @UnresolvedImport @Reimport
+    import renpy.display  # @UnresolvedImport @Reimport
 
     update_path(renpy.display)
 
@@ -359,8 +382,8 @@ def import_all():
     import renpy.display.pgrender
     import renpy.display.scale
     import renpy.display.module
-    import renpy.display.render # Most display stuff depends on this. @UnresolvedImport
-    import renpy.display.core # object @UnresolvedImport
+    import renpy.display.render  # Most display stuff depends on this. @UnresolvedImport
+    import renpy.display.core  # object @UnresolvedImport
 
     import renpy.text
 
@@ -382,13 +405,15 @@ def import_all():
     update_path(renpy.angle)
 
     import renpy.display.layout
-    import renpy.display.motion # layout @UnresolvedImport
-    import renpy.display.behavior # layout @UnresolvedImport
-    import renpy.display.transition # core, layout @UnresolvedImport
-    import renpy.display.movetransition # core @UnresolvedImport
+    import renpy.display.viewport
+    import renpy.display.transform
+    import renpy.display.motion  # layout @UnresolvedImport
+    import renpy.display.behavior  # layout @UnresolvedImport
+    import renpy.display.transition  # core, layout @UnresolvedImport
+    import renpy.display.movetransition  # core @UnresolvedImport
     import renpy.display.im
     import renpy.display.imagelike
-    import renpy.display.image # core, behavior, im, imagelike @UnresolvedImport
+    import renpy.display.image  # core, behavior, im, imagelike @UnresolvedImport
     import renpy.display.video
     import renpy.display.focus
     import renpy.display.anim
@@ -408,6 +433,10 @@ def import_all():
 
     # Note: For windows to work, renpy.audio.audio needs to be after
     # renpy.display.module.
+
+    import renpy.audio
+    update_path(renpy.audio)
+
     import renpy.audio.audio
     import renpy.audio.music
     import renpy.audio.sound
@@ -431,17 +460,24 @@ def import_all():
     import renpy.memory
 
     import renpy.exports
-    import renpy.character # depends on exports. @UnresolvedImport
+    import renpy.character  # depends on exports. @UnresolvedImport
 
     import renpy.add_from
     import renpy.dump
 
-    import renpy.config # depends on lots. @UnresolvedImport
-    import renpy.minstore # depends on lots. @UnresolvedImport
+    import renpy.config  # depends on lots. @UnresolvedImport
+    import renpy.minstore  # depends on lots. @UnresolvedImport
     import renpy.defaultstore  # depends on everything. @UnresolvedImport
 
-    import renpy.main
+    import renpy.test
+    import renpy.test.testmouse
+    import renpy.test.testfocus
+    import renpy.test.testkey
+    import renpy.test.testast
+    import renpy.test.testparser
+    import renpy.test.testexecution
 
+    import renpy.main
 
     # Back up the Ren'Py modules.
 
@@ -459,7 +495,7 @@ def post_import():
     of various modules.
     """
 
-    import renpy # @UnresolvedImport
+    import renpy  # @UnresolvedImport
 
     # Create the store.
     renpy.python.create_store("store")
@@ -498,7 +534,7 @@ def reload_all():
     sys.exc_clear()
 
     # Reset the styles.
-    renpy.style.reset() # @UndefinedVariable
+    renpy.style.reset()  # @UndefinedVariable
 
     # Shut down the cache thread.
     renpy.display.im.cache.quit()
@@ -589,8 +625,5 @@ def import_cython():
     import renpy.angle.gltexture
 
 
-
 if False:
     import renpy.defaultstore as store
-
-
