@@ -33,6 +33,7 @@ import renpy.audio
 sample_alpha = None
 sample_noalpha = None
 
+
 def set_rgba_masks():
     """
     This rebuilds the sample surfaces, to ones that use the given
@@ -65,6 +66,7 @@ def set_rgba_masks():
 
     renpy.audio.audio.sample_surfaces(sample_noalpha, sample_alpha)
 
+
 class Surface(pygame.Surface):
     """
     This allows us to wrap around pygame's surface, to change
@@ -89,6 +91,7 @@ class Surface(pygame.Surface):
         rv = pygame.Surface.subsurface(self, rect)
         return rv
 
+
 def surface((width, height), alpha):
     """
     Constructs a new surface. The allocated surface is actually a subsurface
@@ -111,17 +114,18 @@ def surface((width, height), alpha):
         sample = pygame.Surface((4, 4), pygame.SRCALPHA, 32)
 
     surf = Surface((width + 4, height + 4), 0, sample)
-    return surf.subsurface((2, 2, width, height)) # E1101
+    return surf.subsurface((2, 2, width, height))  # E1101
 
 surface_unscaled = surface
 
+
 def copy_surface(surf, alpha=True):
     """
     Creates a copy of the surface.
     """
 
     rv = surface_unscaled(surf.get_size(), alpha)
-    renpy.display.accelerator.nogil_copy(surf, rv) # @UndefinedVariable
+    renpy.display.accelerator.nogil_copy(surf, rv)  # @UndefinedVariable
     return rv
 
 copy_surface_unscaled = copy_surface
@@ -130,24 +134,30 @@ copy_surface_unscaled = copy_surface
 # Wrapper around image loading.
 
 # Formats we can load reentrantly.
-safe_formats = { "png", "jpg", "jpeg" }
+safe_formats = { "png", "jpg", "jpeg", "webp" }
 
 # Lock used for loading unsafe formats.
 image_load_lock = threading.RLock()
 
+
 def load_image(f, filename):
     global count
 
     _basename, _dot, ext = filename.rpartition('.')
 
-    if ext.lower() in safe_formats:
-        surf = pygame.image.load(f, renpy.exports.fsencode(filename))
-    else:
+    try:
 
-        # Non-whitelisted formats may not be able to load in a reentrant
-        # fashion.
-        with image_load_lock:
+        if ext.lower() in safe_formats:
             surf = pygame.image.load(f, renpy.exports.fsencode(filename))
+        else:
+
+            # Non-whitelisted formats may not be able to load in a reentrant
+            # fashion.
+            with image_load_lock:
+                surf = pygame.image.load(f, renpy.exports.fsencode(filename))
+
+    except Exception as e:
+        raise Exception("Could not load image {!r}: {!r}".format(filename, e))
 
     rv = copy_surface_unscaled(surf)
     return rv
