@@ -1,4 +1,4 @@
-# Copyright 2004-2015 Tom Rothamel <pytom@bishoujo.us>
+# Copyright 2004-2016 Tom Rothamel <pytom@bishoujo.us>
 #
 # Permission is hereby granted, free of charge, to any person
 # obtaining a copy of this software and associated documentation files
@@ -19,6 +19,7 @@
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
+from __future__ import print_function
 import renpy.display
 import time
 import collections
@@ -32,6 +33,7 @@ profile_log = renpy.log.open("profile_screen", developer=True, append=False, flu
 # A map from screen name to ScreenProfile object.
 profile = { }
 
+
 class ScreenProfile(renpy.object.Object):
     """
     :doc: profile_screen
@@ -88,8 +90,8 @@ class ScreenProfile(renpy.object.Object):
             Displays the variables in the screen that are marked as const and
             not-const.
 
-        All profiling profiling output will be logged to profile_screen.txt in
-        the game directory.
+        All profiling output will be logged to profile_screen.txt in the game
+        directory.
         """
 
         self.predict = predict
@@ -107,6 +109,7 @@ class ScreenProfile(renpy.object.Object):
                 name = tuple(name.split())
                 profile[name] = self
 
+
 def get_profile(name):
     """
     Returns the profile object for the screen with `name`, or a default
@@ -130,6 +133,7 @@ def get_profile(name):
 # does not exceed config.screen_cache_size for each screen.
 predict_cache = collections.defaultdict(list)
 
+
 class ScreenCache(object):
     """
     Represents an entry in the screen cache. Upon creation, puts itself into
@@ -154,6 +158,7 @@ class ScreenCache(object):
 
 cache_put = ScreenCache
 
+
 def cache_get(screen, args, kwargs):
     """
     Returns the cache to use when `screen` is accessed with `args` and
@@ -199,7 +204,8 @@ class Screen(renpy.object.Object):
                  predict=None,
                  variant=None,
                  parameters=False,
-                 location=None):
+                 location=None,
+                 layer="screens"):
 
         # The name of this screen.
         if isinstance(name, basestring):
@@ -207,15 +213,19 @@ class Screen(renpy.object.Object):
 
         self.name = name
 
-        screens[name[0], variant] = self
-        screens_by_name[name[0]][variant] = self
+        if (variant is None) or isinstance(variant, basestring):
+            variant = [ variant ]
+
+        for v in variant:
+            screens[name[0], v] = self
+            screens_by_name[name[0]][v] = self
 
         # A function that can be called to display the screen.
         self.function = function
 
         # If this is a SL2 screen, the SLScreen node at the root of this
         # screen.
-        if isinstance(function, renpy.sl2.slast.SLScreen): # @UndefinedVariable
+        if isinstance(function, renpy.sl2.slast.SLScreen):  # @UndefinedVariable
             self.ast = function
         else:
             self.ast = None
@@ -241,6 +251,9 @@ class Screen(renpy.object.Object):
         # The location (filename, linenumber) of this screen.
         self.location = location
 
+        # The layer the screen will be shown on.
+        self.layer = layer
+
         global prepared
         global analyzed
 
@@ -249,7 +262,7 @@ class Screen(renpy.object.Object):
 
 
 # Phases we can be in.
-PREDICT = 0 # Predicting the screen before it is shown.
+PREDICT = 0  # Predicting the screen before it is shown.
 SHOW = 1    # Showing the screen for the first time.
 UPDATE = 2  # Showing the screen for the second and later times.
 HIDE = 3    # After the screen has been hid with "hide screen" (or the end of call screen).
@@ -263,6 +276,7 @@ phase_name = [
     "OLD",
     ]
 
+
 class ScreenDisplayable(renpy.display.layout.Container):
     """
     A screen is a collection of widgets that are displayed together. This
@@ -346,7 +360,6 @@ class ScreenDisplayable(renpy.display.layout.Container):
         else:
             self.use_cache = { }
 
-
         # What widgets and transforms were the last time this screen was
         # updated. Used to communicate with the ui module, and only
         # valid during an update - not used at other times.
@@ -471,7 +484,7 @@ class ScreenDisplayable(renpy.display.layout.Container):
 
         return rv
 
-    def _in_old_scene(self):
+    def _in_current_store(self):
 
         if self.screen is None:
             return self
@@ -487,8 +500,9 @@ class ScreenDisplayable(renpy.display.layout.Container):
 
         rv = self.copy()
         rv.phase = OLD
-        return rv
+        rv.child = self.child._in_current_store()
 
+        return rv
 
     def update(self):
 
@@ -525,16 +539,15 @@ class ScreenDisplayable(renpy.display.layout.Container):
 
             if profile:
                 profile_log.write("%s %s %s",
-                    phase_name[self.phase],
-                    " ".join(self.screen_name),
-                    datetime.datetime.now().strftime("%H:%M:%S.%f"))
+                                  phase_name[self.phase],
+                                  " ".join(self.screen_name),
+                                  datetime.datetime.now().strftime("%H:%M:%S.%f"))
 
                 start = time.time()
 
                 if self.profile.debug:
                     debug = True
 
-
         # Cycle widgets and transforms.
         self.old_widgets = self.widgets
         self.old_transforms = self.transforms
@@ -655,11 +668,13 @@ _current_screen = None
 # The stack of old current screens.
 current_screen_stack = [ ]
 
+
 def push_current_screen(screen):
     global _current_screen
     current_screen_stack.append(_current_screen)
     _current_screen = screen
 
+
 def pop_current_screen():
     _current_screen = current_screen_stack.pop()
 
@@ -672,6 +687,7 @@ screens_by_name = collections.defaultdict(dict)
 # The screens that were updated during the current interaction.
 updated_screens = set()
 
+
 def get_screen_variant(name, candidates=None):
     """
     Get a variant screen object for `name`.
@@ -690,6 +706,7 @@ def get_screen_variant(name, candidates=None):
 
     return None
 
+
 def get_all_screen_variants(name):
     """
     Gets all variants of the screen with `name`.
@@ -716,6 +733,7 @@ prepared = False
 sorted_screens = [ ]
 screens_at_sort = { }
 
+
 def sort_screens():
     """
     Produces a list of SL2 screens in topologically sorted order.
@@ -774,6 +792,7 @@ def sort_screens():
 
     return rv
 
+
 def sorted_variants():
     """
     Produces a list of screen variants in topological order.
@@ -786,6 +805,7 @@ def sorted_variants():
 
     return rv
 
+
 def analyze_screens():
     """
     Analyzes all screens.
@@ -804,6 +824,7 @@ def analyze_screens():
 
     analyzed = True
 
+
 def prepare_screens():
     """
     Prepares all screens for use.
@@ -828,6 +849,7 @@ def prepare_screens():
 
     prepared = True
 
+
 def define_screen(*args, **kwargs):
     """
     :doc: screens
@@ -871,7 +893,23 @@ def define_screen(*args, **kwargs):
     Screen(*args, **kwargs)
 
 
-def get_screen(name, layer="screens"):
+def get_screen_layer(name):
+    """
+    Returns the layer that the screen with `name` is part of.
+    """
+
+    if not isinstance(name, basestring):
+        name = name[0]
+
+    screen = get_screen_variant(name)
+
+    if screen is None:
+        return "screens"
+    else:
+        return screen.layer
+
+
+def get_screen(name, layer=None):
     """
     :doc: screens
 
@@ -892,6 +930,9 @@ def get_screen(name, layer="screens"):
 
     """
 
+    if layer is None:
+        layer = get_screen_layer(name)
+
     if isinstance(name, basestring):
         name = (name, )
 
@@ -926,6 +967,7 @@ def has_screen(name):
     else:
         return False
 
+
 def show_screen(_screen_name, *_args, **kwargs):
     """
     :doc: screens
@@ -954,7 +996,7 @@ def show_screen(_screen_name, *_args, **kwargs):
     initialize the screen's scope.
     """
 
-    _layer = kwargs.pop("_layer", "screens")
+    _layer = kwargs.pop("_layer", None)
     _tag = kwargs.pop("_tag", None)
     _widget_properties = kwargs.pop("_widget_properties", {})
     _transient = kwargs.pop("_transient", False)
@@ -969,6 +1011,9 @@ def show_screen(_screen_name, *_args, **kwargs):
     if screen is None:
         raise Exception("Screen %s is not known.\n" % (name[0],))
 
+    if _layer is None:
+        _layer = get_screen_layer(name)
+
     if _tag is None:
         _tag = screen.tag
 
@@ -1011,7 +1056,7 @@ def predict_screen(_screen_name, *_args, **kwargs):
     initialize the screen's scope.
     """
 
-    _layer = kwargs.pop("_layer", "screens")
+    _layer = kwargs.pop("_layer", None)
     _tag = kwargs.pop("_tag", None)
     _widget_properties = kwargs.pop("_widget_properties", {})
     _transient = kwargs.pop("_transient", False)
@@ -1029,6 +1074,9 @@ def predict_screen(_screen_name, *_args, **kwargs):
     if screen is None:
         return
 
+    if _layer is None:
+        _layer = get_screen_layer(name)
+
     scope = { }
     scope["_scope"] = scope
 
@@ -1057,13 +1105,13 @@ def predict_screen(_screen_name, *_args, **kwargs):
         if renpy.config.debug_image_cache:
             import traceback
 
-            print "While predicting screen", _screen_name
+            print("While predicting screen", _screen_name)
             traceback.print_exc()
 
     renpy.ui.reset()
 
 
-def hide_screen(tag, layer='screens'):
+def hide_screen(tag, layer=None):
     """
     :doc: screens
 
@@ -1072,11 +1120,15 @@ def hide_screen(tag, layer='screens'):
     Hides the screen with `tag` on `layer`.
     """
 
+    if layer is None:
+        layer = get_screen_layer((tag,))
+
     screen = get_screen(tag, layer)
 
     if screen is not None:
         renpy.exports.hide(screen.tag, layer=layer)
 
+
 def use_screen(_screen_name, *_args, **kwargs):
 
     _name = kwargs.pop("_name", ())
@@ -1110,10 +1162,12 @@ def use_screen(_screen_name, *_args, **kwargs):
 
     _current_screen.old_transfers = old_transfers
 
+
 def current_screen():
     return _current_screen
 
-def get_widget(screen, id, layer='screens'): #@ReservedAssignment
+
+def get_widget(screen, id, layer=None):  # @ReservedAssignment
     """
     :doc: screens
 
@@ -1128,6 +1182,9 @@ def get_widget(screen, id, layer='screens'): #@ReservedAssignment
     if screen is None:
         screen = current_screen()
     else:
+        if layer is None:
+            layer = get_screen_layer(screen)
+
         screen = get_screen(screen, layer)
 
     if not isinstance(screen, ScreenDisplayable):
@@ -1139,7 +1196,8 @@ def get_widget(screen, id, layer='screens'): #@ReservedAssignment
     rv = screen.widgets.get(id, None)
     return rv
 
-def get_widget_properties(id, screen=None, layer='screens'): # @ReservedAssignment
+
+def get_widget_properties(id, screen=None, layer=None):  # @ReservedAssignment
     """
     :doc: screens
 
@@ -1156,6 +1214,9 @@ def get_widget_properties(id, screen=None, layer='screens'): # @ReservedAssignme
     if screen is None:
         s = current_screen()
     else:
+        if layer is None:
+            layer = get_screen_layer(screen)
+
         s = get_screen(screen, layer)
 
     if s is None:
@@ -1168,6 +1229,7 @@ def get_widget_properties(id, screen=None, layer='screens'): # @ReservedAssignme
 
     return rv
 
+
 def before_restart():
     """
     This is called before Ren'Py restarts to put the screens into restart
@@ -1193,7 +1255,7 @@ def show_overlay_screens(suppress_overlay):
 
     if renpy.store._overlay_screens is None:
         show = show
-    if renpy.store._overlay_screens is True:
+    elif renpy.store._overlay_screens is True:
         show = True
     else:
         show = False
