@@ -1,4 +1,4 @@
-# Copyright 2004-2015 Tom Rothamel <pytom@bishoujo.us>
+# Copyright 2004-2016 Tom Rothamel <pytom@bishoujo.us>
 #
 # Permission is hereby granted, free of charge, to any person
 # obtaining a copy of this software and associated documentation files
@@ -38,12 +38,22 @@ import renpy
 from json import dumps as json_dumps
 
 # Dump that chooses which pickle to use:
+
+
 def dump(o, f):
     if renpy.config.use_cpickle:
         cPickle.dump(o, f, cPickle.HIGHEST_PROTOCOL)
     else:
         pickle.dump(o, f, pickle.HIGHEST_PROTOCOL)
 
+
+def dumps(o):
+    if renpy.config.use_cpickle:
+        return cPickle.dumps(o, cPickle.HIGHEST_PROTOCOL)
+    else:
+        return pickle.dumps(o, pickle.HIGHEST_PROTOCOL)
+
+
 def loads(s):
     if renpy.config.use_cpickle:
         return cPickle.loads(s)
@@ -54,6 +64,7 @@ def loads(s):
 # files.
 savegame_suffix = renpy.savegame_suffix
 
+
 def save_dump(roots, log):
     """
     Dumps information about the save to save_dump.txt. We dump the size
@@ -63,7 +74,6 @@ def save_dump(roots, log):
 
     o_repr_cache = { }
 
-
     def visit(o, path):
         ido = id(o)
 
@@ -95,7 +105,6 @@ def save_dump(roots, log):
         else:
             o_repr = "BAD TYPE <{0}>".format(type(o).__name__)
 
-
         o_repr_cache[ido] = o_repr
 
         if isinstance(o, (int, float, types.NoneType, types.ModuleType, types.ClassType)):
@@ -161,7 +170,6 @@ def save_dump(roots, log):
                 size += 2
                 size += visit(v, "{0}[{1!r}]".format(path, k))
 
-
         f.write("{0: 7d} {1} = {2}\n".format(size, path, o_repr_cache[ido]))
 
         return size
@@ -179,9 +187,12 @@ def save_dump(roots, log):
 
 # Used to indicate an aborted save, due to the game being mutated
 # while the save is in progress.
+
+
 class SaveAbort(Exception):
     pass
 
+
 def safe_rename(old, new):
     """
     Safely rename old to new.
@@ -192,6 +203,7 @@ def safe_rename(old, new):
 
     os.rename(old, new)
 
+
 class SaveRecord(object):
     """
     This is passed to the save locations. It contains the information that
@@ -244,7 +256,6 @@ class SaveRecord(object):
         self.first_filename = filename
 
 
-
 def save(slotname, extra_info='', mutate_flag=False):
     """
     :doc: loadsave
@@ -293,7 +304,6 @@ def save(slotname, extra_info='', mutate_flag=False):
     clear_slot(slotname)
 
 
-
 # Flag that lets us know if an autosave is in progress.
 autosave_not_running = threading.Event()
 autosave_not_running.set()
@@ -301,6 +311,7 @@ autosave_not_running.set()
 # The number of times autosave has been called without a save occuring.
 autosave_counter = 0
 
+
 def autosave_thread(take_screenshot):
 
     global autosave_counter
@@ -329,7 +340,6 @@ def autosave_thread(take_screenshot):
         autosave_not_running.set()
 
 
-
 def autosave():
     global autosave_counter
 
@@ -369,7 +379,6 @@ def force_autosave(take_screenshot=False):
         screenshot will be used.
     """
 
-
     # That is, autosave is running.
     if not autosave_not_running.isSet():
         return
@@ -490,6 +499,7 @@ def list_slots(regexp=None):
 # A cache for newest slot info.
 newest_slot_cache = { }
 
+
 def newest_slot(regexp=None):
     """
     :doc: loadsave
@@ -534,6 +544,7 @@ def slot_mtime(slotname):
 
     return get_cache(slotname).get_mtime()
 
+
 def slot_json(slotname):
     """
     :doc: loadsave
@@ -544,6 +555,7 @@ def slot_json(slotname):
 
     return get_cache(slotname).get_json()
 
+
 def slot_screenshot(slotname):
     """
     :doc: loadsave
@@ -554,6 +566,7 @@ def slot_screenshot(slotname):
 
     return get_cache(slotname).get_screenshot()
 
+
 def can_load(filename, test=False):
     """
     :doc: loadsave
@@ -568,6 +581,7 @@ def can_load(filename, test=False):
     else:
         return False
 
+
 def load(filename):
     """
     :doc: loadsave
@@ -579,6 +593,7 @@ def load(filename):
     roots, log = loads(location.load(filename))
     log.unfreeze(roots, label="_after_load")
 
+
 def unlink_save(filename):
     """
     :doc: loadsave
@@ -603,6 +618,7 @@ def rename_save(old, new):
     clear_slot(old)
     clear_slot(new)
 
+
 def copy_save(old, new):
     """
     :doc: loadsave
@@ -636,6 +652,7 @@ def cycle_saves(name, count):
 # None is a possible value for some of the attributes.
 unknown = renpy.object.Sentinel("unknown")
 
+
 class Cache(object):
     """
     This represents cached information about a save slot.
@@ -686,6 +703,7 @@ class Cache(object):
 # data until the slot changes.
 cache = { }
 
+
 def get_cache(slotname):
 
     rv = cache.get(slotname, None)
@@ -707,6 +725,7 @@ def clear_slot(slotname):
 
     renpy.exports.restart_interaction()
 
+
 def clear_cache():
     """
     Clears the entire cache.
@@ -726,6 +745,3 @@ location = None
 
 if False:
     location = renpy.savelocation.FileLocation("blah")
-
-
-
