@@ -30,10 +30,11 @@ import renpy.text.font as font
 import renpy.text.extras as extras
 
 try:
-    from _renpybidi import log2vis, WRTL, RTL, ON # @UnresolvedImport
+    from _renpybidi import log2vis, WRTL, RTL, ON  # @UnresolvedImport
 except:
     pass
 
+
 class Blit(object):
     """
     Represents a blit command, which can be used to render a texture to a
@@ -97,7 +98,6 @@ def outline_blits(blits, outline):
     # The y coordinate of the bottom of the current line.
     bottom_y = 0
 
-
     # The maximum x coordinate of the previous blit on this line.
     max_x = 0
 
@@ -288,7 +288,6 @@ class TextSegment(object):
         on the font group.
         """
 
-
         if not isinstance(self.font, font.FontGroup):
             yield (self, s)
             return
@@ -320,6 +319,7 @@ class TextSegment(object):
         fo = font.get_font(self.font, self.size, self.bold, self.italic, 0, self.antialias, self.vertical, self.hinting, layout.oversample)
         return fo.bounds(glyphs, bounds)
 
+
 class SpaceSegment(object):
     """
     A segment that's used to render horizontal or vertical whitespace.
@@ -423,6 +423,7 @@ class DisplayableSegment(object):
     def bounds(self, glyphs, bounds, layout):
         return bounds
 
+
 class FlagSegment(object):
     """
     A do-nothing segment that just exists so we can flag the start and end
@@ -441,6 +442,7 @@ class FlagSegment(object):
     def bounds(self, glyphs, bounds, layout):
         return bounds
 
+
 class Layout(object):
     """
     Represents the layout of text.
@@ -590,7 +592,7 @@ class Layout(object):
             self.paragraph_glyphs.append(list(par_glyphs))
 
             if splits_from:
-                textsupport.copy_splits(splits_from.paragraph_glyphs[p_num], par_glyphs) # @UndefinedVariable
+                textsupport.copy_splits(splits_from.paragraph_glyphs[p_num], par_glyphs)  # @UndefinedVariable
 
             else:
 
@@ -686,7 +688,7 @@ class Layout(object):
             target_x = self.scale_int(splits_from.size[0] - splits_from.xborder)
             target_y = self.scale_int(splits_from.size[1] - splits_from.yborder)
 
-            textsupport.tweak_glyph_spacing(all_glyphs, lines, target_x - maxx, target_y - y, maxx, y) # @UndefinedVariable
+            textsupport.tweak_glyph_spacing(all_glyphs, lines, target_x - maxx, target_y - y, maxx, y)  # @UndefinedVariable
 
             maxx = target_x
             y = target_y
@@ -751,7 +753,6 @@ class Layout(object):
 
                 ts.draw(glyphs, di, self.add_left, self.add_top, self)
 
-
             renpy.display.draw.mutated_surface(surf)
             tex = renpy.display.draw.load_texture(surf)
 
@@ -782,7 +783,6 @@ class Layout(object):
                 renpy.display.to_log.write("     Available: (%d, %d) Laid-out: (%d, %d)", width, height, sw, sh)
                 renpy.display.to_log.write("     Text: %r", text.text)
 
-
     def scale(self, n):
         if n is None:
             return n
@@ -807,7 +807,6 @@ class Layout(object):
 
         return n * int(self.oversample)
 
-
     def unscale_pair(self, x, y):
         return x / self.oversample, y / self.oversample
 
@@ -854,7 +853,7 @@ class Layout(object):
 
             line.extend(tss[-1].subsegment(u" "))
 
-        for type, text in tokens: #@ReservedAssignment
+        for type, text in tokens:  # @ReservedAssignment
 
             if type == PARAGRAPH:
 
@@ -1070,7 +1069,6 @@ class Layout(object):
 
         return l, rtl
 
-
     def figure_outlines(self, style):
         """
         Return a list containing the outlines, including an outline
@@ -1095,7 +1093,6 @@ class Layout(object):
             for dsx, dsy in dslist:
                 outlines.append((0, style.drop_shadow_color, self.scale_outline(dsx), self.scale_outline(dsy)))
 
-
         for size, color, xo, yo in style_outlines:
             outlines.append((self.scale_outline(size), color, self.scale_outline(xo), self.scale_outline(yo)))
 
@@ -1128,7 +1125,6 @@ class Layout(object):
 
         return outlines, right - left, bottom - top, -left, -top
 
-
     def blits_typewriter(self, st):
         """
         Given a st and an outline, returns a list of blit objects that
@@ -1171,7 +1167,6 @@ class Layout(object):
         min_x = width
         max_x = 0
 
-
         left = False
         right = False
 
@@ -1227,7 +1222,6 @@ virtual_layout_cache_old = { }
 virtual_layout_cache_new = { }
 
 
-
 def layout_cache_clear():
     """
     Clears the old and new layout caches.
@@ -1258,6 +1252,7 @@ def layout_cache_tick():
 VERT_REVERSE = renpy.display.render.Matrix2D(0, -1, 1, 0)
 VERT_FORWARD = renpy.display.render.Matrix2D(0, 1, -1, 0)
 
+
 class Text(renpy.display.core.Displayable):
 
     """
@@ -1287,6 +1282,8 @@ class Text(renpy.display.core.Displayable):
     __version__ = 4
 
     _uses_scope = True
+    _duplicatable = False
+    locked = False
 
     def after_upgrade(self, version):
 
@@ -1360,6 +1357,28 @@ class Text(renpy.display.core.Displayable):
         # The list of displayables we use.
         self.displayables = None
 
+        self._duplicatable = self.slow
+
+    def _duplicate(self, args):
+        if self._duplicatable:
+            return self._copy(args)
+
+        return self
+
+    def _in_current_store(self):
+        if not self._uses_scope:
+            return self
+
+        rv = self._copy()
+
+        if rv.displayables is not None:
+            rv.displayables = [ i._in_current_store() for i in rv.displayables ]
+
+        rv.slow_done = None
+        rv.locked = True
+
+        return rv
+
     def __unicode__(self):
         s = ""
 
@@ -1379,10 +1398,16 @@ class Text(renpy.display.core.Displayable):
         Called to update the scope, when necessary.
         """
 
+        if self.locked:
+            return False
+
         return self.set_text(self.text_parameter, scope, self.substitute, update)
 
     def set_text(self, text, scope=None, substitute=False, update=True):
 
+        if self.locked:
+            return
+
         old_text = self.text
 
         if not isinstance(text, list):
@@ -1401,7 +1426,10 @@ class Text(renpy.display.core.Displayable):
                     i, did_sub = renpy.substitutions.substitute(i, scope, substitute)
                     uses_scope = uses_scope or did_sub
 
-                i = unicode(i)
+                if isinstance(i, str):
+                    i = unicode(i, "utf-8", "replace")
+                else:
+                    i = unicode(i)
 
             new_text.append(i)
 
@@ -1487,7 +1515,6 @@ class Text(renpy.display.core.Displayable):
         # Text.
         self.tokens, self.displayables = self.get_displayables(tokens)
 
-
     def visit(self):
 
         if self.dirty or self.displayables is None:
@@ -1509,7 +1536,7 @@ class Text(renpy.display.core.Displayable):
         rv = "".join(rv)
         _, _, rv = rv.rpartition("{fast}")
 
-        rv = renpy.translation.notags_filter(rv)
+        rv = renpy.translation.dialogue.notags_filter(rv)
 
         alt = self.style.alt
 
@@ -1534,7 +1561,6 @@ class Text(renpy.display.core.Displayable):
         virtual_layout_cache_old.pop(key, None)
         virtual_layout_cache_new.pop(key, None)
 
-
     def get_layout(self):
         """
         Gets the layout of this text, if one exists.
@@ -1582,7 +1608,6 @@ class Text(renpy.display.core.Displayable):
         if hyperlink_focus:
             return hyperlink_focus(target)
 
-
     def set_style_prefix(self, prefix, root):
         if prefix != self.style.prefix:
             self.kill_layout()
@@ -1633,7 +1658,7 @@ class Text(renpy.display.core.Displayable):
                 return rv
 
         if (self.is_focused() and
-            renpy.display.behavior.map_event(ev, "button_select")):
+                renpy.display.behavior.map_event(ev, "button_select")):
 
             clicked = self.style.hyperlink_functions[1]
 
@@ -1671,8 +1696,10 @@ class Text(renpy.display.core.Displayable):
 
         layout = self.get_layout()
 
+        # If we haven't been laid out, either the text isn't being shown,
+        # or it's not animated
         if layout is None:
-            return 60.0
+            return 0.0
 
         return layout.max_time
 
@@ -1797,13 +1824,12 @@ class Text(renpy.display.core.Displayable):
                 else:
                     b_y += layout.add_top
 
-
                 # Blit.
                 rv.absolute_blit(
                     tex.subsurface((b_x, b_y, b_w, b_h)),
                     layout.unscale_pair(b_x + xo + layout.xoffset - o - layout.add_left,
-                     b_y + yo + layout.yoffset - o - layout.add_top)
-                     )
+                                        b_y + yo + layout.yoffset - o - layout.add_top)
+                    )
 
         # Blit displayables.
         if layout.displayable_blits:
@@ -1848,7 +1874,6 @@ class Text(renpy.display.core.Displayable):
 
         return rv
 
-
     def tokenize(self, text):
         """
         Convert the text into a list of tokens.
@@ -1872,7 +1897,6 @@ class Text(renpy.display.core.Displayable):
 
         return tokens
 
-
     def apply_custom_tags(self, tokens):
         """
         Apply new-style custom text tags.
@@ -1985,4 +2009,3 @@ language_tailor = textsupport.language_tailor
 
 # Compatibility, in case one of these was pickled.
 ParameterizedText = extras.ParameterizedText
-
