@@ -30,9 +30,12 @@ import sys
 import renpy.display
 import renpy.text
 
+from renpy.display.behavior import is_selected, is_sensitive
+
 ##############################################################################
 # Special classes that can be subclassed from the outside.
 
+
 class Action(renpy.object.Object):
     """
     This can be passed to the clicked method of a button or hotspot. It is
@@ -58,6 +61,7 @@ class Action(renpy.object.Object):
     def __call__(self):
         raise Exception("Not implemented")
 
+
 class BarValue(renpy.object.Object):
     """
     This can be passed to the value method of bar and hotbar.
@@ -91,7 +95,9 @@ class Addable(object):
     def get_layer(self):
         return Exception("Operation can only be performed on a layer.")
 
+
 class Layer(Addable):
+
     def __init__(self, name):
         self.name = name
 
@@ -131,13 +137,13 @@ class Many(Addable):
             imagemap = imagemap_stack.pop()
             imagemap.cache.finish()
 
-
         if d and d != self.displayable:
             raise Exception("ui.close closed %r, not the expected %r." % (self.displayable, d))
 
     def __repr__(self):
         return "<Many: %r>" % self.displayable
 
+
 class One(Addable):
     """
     A widget that expects exactly one child.
@@ -157,6 +163,7 @@ class One(Addable):
     def __repr__(self):
         return "<One: %r>" % self.displayable
 
+
 class Detached(Addable):
     """
     Used to indicate a widget is detached from the stack.
@@ -172,6 +179,7 @@ class Detached(Addable):
     def close(self, d):
         raise Exception("Detached expects to be given a child.")
 
+
 class ChildOrFixed(Addable):
     """
     If one widget is added, then it is added directly to our
@@ -228,16 +236,16 @@ def reset():
 
 renpy.game.post_init.append(reset)
 
-def interact(type='misc', roll_forward=None, **kwargs): #@ReservedAssignment
+
+def interact(type='misc', roll_forward=None, **kwargs):  # @ReservedAssignment
     """
     :doc: ui
     :args: (roll_forward=None, mouse='default')
 
     Causes an interaction with the user, and returns the result of that
-    interaction. This causes Ren'Py to to redraw the screen and begin
-    processing input events. When a displayable returns a value in
-    response to an event, that value is returned from ui.interact,
-    and the interaction ends.
+    interaction. This causes Ren'Py to redraw the screen and begin processing
+    input events. When a displayable returns a value in response to an event,
+    that value is returned from ui.interact, and the interaction ends.
 
     This function is rarely called directly. It is usually called by other
     parts of Ren'Py, including the say statement, menu statement, with statement,
@@ -283,10 +291,12 @@ def interact(type='misc', roll_forward=None, **kwargs): #@ReservedAssignment
     else:
         return rv
 
+
 def tag(name):
     global add_tag
     add_tag = name
 
+
 def child_or_fixed():
     """
     Causes the current widget to be given child-fixed semantics. This
@@ -297,14 +307,17 @@ def child_or_fixed():
 
     stack.append(ChildOrFixed(stack[-1].style_prefix))
 
+
 def remove(d):
     layer = stack[-1].get_layer()
     renpy.game.context(-1).scene_lists.remove(layer, d)
 
+
 def remove_above(d):
     layer = stack[-1].get_layer()
     renpy.game.context(-1).scene_lists.remove_above(layer, d)
 
+
 def at(transform):
     """
     :doc: ui
@@ -316,10 +329,12 @@ def at(transform):
 
     at_stack.append(transform)
 
+
 def clear():
     layer = stack[-1].get_layer()
     renpy.game.context(-1).scene_lists.clear(layer)
 
+
 def detached():
     """
     :doc: ui
@@ -332,6 +347,7 @@ def detached():
     stack.append(rv)
     return rv
 
+
 def layer(name):
     """
     :doc: ui
@@ -342,6 +358,7 @@ def layer(name):
 
     stack.append(Layer(name))
 
+
 def close(d=None):
     """
     :doc: ui
@@ -357,6 +374,7 @@ def close(d=None):
     if not stack:
         raise Exception("ui.close() called when no layer or widget is open.")
 
+
 def reopen(w, clear):
 
     stack.append(Many(w))
@@ -364,17 +382,20 @@ def reopen(w, clear):
     if clear:
         w.children[:] = [ ]
 
+
 def context_enter(w):
     if isinstance(renpy.ui.stack[-1], renpy.ui.Many) and renpy.ui.stack[-1].displayable is w:
         return
 
     raise Exception("%r cannot be used as a context manager.", type(w).__name__)
 
+
 def context_exit(w):
     close(w)
 
 NoStylePrefixGiven = renpy.object.Sentinel("NoStylePrefixGiven")
 
+
 def combine_style(style_prefix, style_suffix):
     """
     Combines a style prefix and style suffix to create a style name, then
@@ -386,7 +407,8 @@ def combine_style(style_prefix, style_suffix):
     else:
         new_style = style_prefix + "_" + style_suffix
 
-    return renpy.style.get_style(new_style) # @UndefinedVariable
+    return renpy.style.get_style(new_style)  # @UndefinedVariable
+
 
 def prefixed_style(style_suffix):
     """
@@ -400,6 +422,7 @@ def prefixed_style(style_suffix):
 # screen.
 screen = None
 
+
 class Wrapper(renpy.object.Object):
 
     def __reduce__(self):
@@ -437,7 +460,7 @@ class Wrapper(renpy.object.Object):
 
         # Pull out the special kwargs, widget_id, at, and style_prefix.
 
-        widget_id = kwargs.pop("id", None) #@ReservedAssignment
+        widget_id = kwargs.pop("id", None)  # @ReservedAssignment
 
         at_list = kwargs.pop("at", [ ])
         if not isinstance(at_list, (list, tuple)):
@@ -486,13 +509,13 @@ class Wrapper(renpy.object.Object):
 
         try:
             w = self.function(*args, **keyword)
-        except TypeError, e:
+        except TypeError as e:
             etype, e, tb = sys.exc_info(); etype
 
             if tb.tb_next is None:
                 e.args = (e.args[0].replace("__call__", "ui." + self.name), )
 
-            del tb # Important! Prevents memory leaks via our frame.
+            del tb  # Important! Prevents memory leaks via our frame.
             raise
 
         main = w._main or w
@@ -544,44 +567,15 @@ class Wrapper(renpy.object.Object):
 
         return main
 
-##############################################################################
-# Button support functions
-def is_selected(clicked):
-
-    if isinstance(clicked, (list, tuple)):
-        for i in clicked:
-            if isinstance(i, renpy.store.SelectedIf): # @UndefinedVariable
-                return i.get_selected()
-        return any(is_selected(i) for i in clicked)
-
-    elif isinstance(clicked, Action):
-        return clicked.get_selected()
-
-    else:
-        return False
-
-def is_sensitive(clicked):
-
-    if isinstance(clicked, (list, tuple)):
-        for i in clicked:
-            if isinstance(i, renpy.store.SensitiveIf): # @UndefinedVariable
-                return i.get_sensitive()
-        return all(is_sensitive(i) for i in clicked)
-
-    elif isinstance(clicked, Action):
-        return clicked.get_sensitive()
-
-    else:
-        return True
-
-
 
 ##############################################################################
 # Widget functions.
 
 def _add(d, **kwargs):
     d = renpy.easy.displayable(d)
-    d = d.parameterize('displayable', [ ])
+
+    if d._duplicatable:
+        d = d._duplicate(None)
 
     rv = d
 
@@ -592,6 +586,7 @@ def _add(d, **kwargs):
 
 add = Wrapper(_add)
 
+
 def _implicit_add(d):
     """
     A faster version of add to use when we know `d` is a displayable and isn't
@@ -602,9 +597,13 @@ def _implicit_add(d):
 
 implicit_add = Wrapper(_implicit_add)
 
+
 def _image(im, **properties):
     d = renpy.display.im.image(im, loose=True, **properties)
-    d = d.parameterize('displayable', [ ])
+
+    if d._duplicatable:
+        d = d._duplicate(None)
+
     return d
 
 image = Wrapper(_image)
@@ -617,6 +616,7 @@ fixed = Wrapper(renpy.display.layout.MultiBox, layout="fixed", style="fixed", ma
 grid = Wrapper(renpy.display.layout.Grid, style="grid", many=True)
 side = Wrapper(renpy.display.layout.Side, style="side", many=True)
 
+
 def _sizer(maxwidth=None, maxheight=None, **properties):
     return renpy.display.layout.Container(xmaximum=maxwidth, ymaximum=maxheight, **properties)
 
@@ -629,6 +629,7 @@ saybehavior = Wrapper(renpy.display.behavior.SayBehavior)
 pausebehavior = Wrapper(renpy.display.behavior.PauseBehavior)
 soundstopbehavior = Wrapper(renpy.display.behavior.SoundStopBehavior)
 
+
 def _key(key, action=None, activate_sound=None):
 
     if action is None:
@@ -638,6 +639,7 @@ def _key(key, action=None, activate_sound=None):
 
 key = Wrapper(_key)
 
+
 class ChoiceActionBase(Action):
     """
     Base class for choice actions. The choice is identified by a label
@@ -647,6 +649,7 @@ class ChoiceActionBase(Action):
     If a location is supplied, it will check whether the choice was
     previously visited and mark it so if it is chosen.
     """
+
     def __init__(self, label, value, location=None, block_all=None):
         self.label = label
         self.value = value
@@ -665,7 +668,6 @@ class ChoiceActionBase(Action):
             if self.chosen is None:
                 self.chosen = renpy.game.persistent._chosen = { }
 
-
     def get_sensitive(self):
         return not renpy.exports.in_fixed_rollback() or (not self.block_all and self.get_selected())
 
@@ -679,6 +681,7 @@ class ChoiceActionBase(Action):
 
         return (self.location, self.label) in self.chosen
 
+
 class ChoiceReturn(ChoiceActionBase):
     """
     :doc: blockrollback
@@ -716,14 +719,13 @@ class ChoiceReturn(ChoiceActionBase):
         to :func:`ui.interact`.
     """
 
-
-
     def __call__(self):
         if self.chosen is not None:
             self.chosen[(self.location, self.label)] = True
 
         return self.value
 
+
 class ChoiceJump(ChoiceActionBase):
     """
     :doc: blockrollback
@@ -761,7 +763,6 @@ class ChoiceJump(ChoiceActionBase):
         to :func:`ui.interact`.
     """
 
-
     def get_selected(self):
         roll_forward = renpy.exports.roll_forward_info()
 
@@ -779,7 +780,7 @@ class ChoiceJump(ChoiceActionBase):
 
 
 def menu(menuitems,
-         style = 'menu',
+         style='menu',
          caption_style='menu_caption',
          choice_style='menu_choice',
          choice_chosen_style='menu_choice_chosen',
@@ -805,8 +806,8 @@ def menu(menuitems,
             clicked = ChoiceReturn(label, val, location)
 
             if clicked.get_chosen():
-                    text = choice_chosen_style
-                    button = choice_chosen_button_style
+                text = choice_chosen_style
+                button = choice_chosen_button_style
 
             if isinstance(button, basestring):
                 button = getattr(renpy.game.style, button)
@@ -825,7 +826,8 @@ def menu(menuitems,
 
     close()
 
-input = Wrapper(renpy.display.behavior.Input, exclude='{}', style="input", replaces=True) #@ReservedAssignment
+input = Wrapper(renpy.display.behavior.Input, exclude='{}', style="input", replaces=True)  # @ReservedAssignment
+
 
 def imagemap_compat(ground,
                     selected,
@@ -856,8 +858,8 @@ def imagemap_compat(ground,
 
         imagebutton(renpy.display.layout.LiveCrop((x0, y0, x1 - x0, y1 - y0), unselected),
                     selected_img,
-                    selected_idle_image = selected_img,
-                    selected_insensitive_image = selected_img,
+                    selected_idle_image=selected_img,
+                    selected_insensitive_image=selected_img,
                     clicked=action,
                     style=button_style[result],
                     xpos=x0,
@@ -871,14 +873,15 @@ def imagemap_compat(ground,
 
 button = Wrapper(renpy.display.behavior.Button, style='button', one=True)
 
-def _imagebutton(idle_image = None,
-                 hover_image = None,
-                 insensitive_image = None,
-                 activate_image = None,
-                 selected_idle_image = None,
-                 selected_hover_image = None,
-                 selected_insensitive_image = None,
-                 selected_activate_image = None,
+
+def _imagebutton(idle_image=None,
+                 hover_image=None,
+                 insensitive_image=None,
+                 activate_image=None,
+                 selected_idle_image=None,
+                 selected_hover_image=None,
+                 selected_insensitive_image=None,
+                 selected_activate_image=None,
                  idle=None,
                  hover=None,
                  insensitive=None,
@@ -912,18 +915,19 @@ def _imagebutton(idle_image = None,
     selected_insensitive = choice(selected_insensitive, selected_insensitive_image, "selected_insensitive")
 
     return renpy.display.behavior.ImageButton(
-            idle,
-            hover,
-            insensitive_image = insensitive,
-            activate_image = activate_image,
-            selected_idle_image = selected_idle,
-            selected_hover_image = selected_hover,
-            selected_insensitive_image = selected_insensitive,
-            selected_activate_image = selected_activate_image,
-            **properties)
+        idle,
+        hover,
+        insensitive_image=insensitive,
+        activate_image=activate_image,
+        selected_idle_image=selected_idle,
+        selected_hover_image=selected_hover,
+        selected_insensitive_image=selected_insensitive,
+        selected_activate_image=selected_activate_image,
+        **properties)
 
 imagebutton = Wrapper(_imagebutton, style="image_button")
 
+
 def _textbutton(label, clicked=None, style=None, text_style=None, substitute=True, scope=None, **kwargs):
 
     text_kwargs, button_kwargs = renpy.easy.split_properties(kwargs, "text_", "")
@@ -939,7 +943,7 @@ def _textbutton(label, clicked=None, style=None, text_style=None, substitute=Tru
         style = prefixed_style("button")
 
     if text_style is None:
-        text_style = renpy.style.get_text_style(style, prefixed_style('button_text')) # @UndefinedVariable
+        text_style = renpy.style.get_text_style(style, prefixed_style('button_text'))  # @UndefinedVariable
 
     rv = renpy.display.behavior.Button(style=style, clicked=clicked, **button_kwargs)
     text = renpy.text.text.Text(label, style=text_style, substitute=substitute, scope=scope, **text_kwargs)
@@ -950,6 +954,7 @@ def _textbutton(label, clicked=None, style=None, text_style=None, substitute=Tru
 
 textbutton = Wrapper(_textbutton)
 
+
 def _label(label, style=None, text_style=None, substitute=True, scope=None, **kwargs):
 
     text_kwargs, label_kwargs = renpy.easy.split_properties(kwargs, "text_", "")
@@ -958,7 +963,7 @@ def _label(label, style=None, text_style=None, substitute=True, scope=None, **kw
         style = prefixed_style('label')
 
     if text_style is None:
-        text_style = renpy.style.get_text_style(style, prefixed_style('label_text')) # @UndefinedVariable
+        text_style = renpy.style.get_text_style(style, prefixed_style('label_text'))  # @UndefinedVariable
 
     rv = renpy.display.layout.Window(None, style=style, **label_kwargs)
     text = renpy.text.text.Text(label, style=text_style, substitute=substitute, scope=scope, **text_kwargs)
@@ -971,16 +976,17 @@ label = Wrapper(_label)
 
 adjustment = renpy.display.behavior.Adjustment
 
+
 def _bar(*args, **properties):
 
     if len(args) == 4:
-        width, height, range, value = args #@ReservedAssignment
+        width, height, range, value = args  # @ReservedAssignment
     if len(args) == 2:
-        range, value = args #@ReservedAssignment
+        range, value = args  # @ReservedAssignment
         width = None
         height = None
     else:
-        range = 1 #@ReservedAssignment
+        range = 1  # @ReservedAssignment
         value = 0
         width = None
         height = None
@@ -992,7 +998,7 @@ def _bar(*args, **properties):
         height  = properties.pop("height")
 
     if "range" in properties:
-        range = properties.pop("range") #@ReservedAssignment
+        range = properties.pop("range")  # @ReservedAssignment
 
     if "value" in properties:
         value = properties.pop("value")
@@ -1018,7 +1024,8 @@ vslider = Wrapper(_bar, style='vslider', replaces=True)
 scrollbar = Wrapper(_bar, style='scrollbar', replaces=True)
 vscrollbar = Wrapper(_bar, style='vscrollbar', replaces=True)
 
-def _autobar_interpolate(range, start, end, time, st, at, **properties): #@ReservedAssignment
+
+def _autobar_interpolate(range, start, end, time, st, at, **properties):  # @ReservedAssignment
 
     if st > time:
         t = 1.0
@@ -1032,7 +1039,8 @@ def _autobar_interpolate(range, start, end, time, st, at, **properties): #@Reser
 
 autobar_interpolate = renpy.curry.curry(_autobar_interpolate)
 
-def _autobar(range, start, end, time, **properties): #@ReservedAssignment
+
+def _autobar(range, start, end, time, **properties):  # @ReservedAssignment
     return renpy.display.layout.DynamicDisplayable(autobar_interpolate(range, start, end, time, **properties))
 
 autobar = Wrapper(_autobar)
@@ -1041,6 +1049,7 @@ transform = Wrapper(renpy.display.motion.Transform, one=True, style='transform')
 _viewport = Wrapper(renpy.display.viewport.Viewport, one=True, replaces=True, style='viewport')
 _vpgrid = Wrapper(renpy.display.viewport.VPGrid, many=True, replaces=True, style='vpgrid')
 
+
 def viewport_common(vpfunc, scrollbars=None, **properties):
 
     if scrollbars is None:
@@ -1098,9 +1107,11 @@ def viewport_common(vpfunc, scrollbars=None, **properties):
 
         return rv
 
+
 def viewport(**properties):
     return viewport_common(_viewport, **properties)
 
+
 def vpgrid(**properties):
     return viewport_common(_vpgrid, **properties)
 
@@ -1155,7 +1166,6 @@ def _imagemap(ground=None, hover=None, insensitive=None, idle=None, selected_hov
 
         raise Exception("Could not find a %s image for imagemap." % name)
 
-
     ground = pick(ground, "ground", None)
     idle = pick(idle, "idle", ground)
     selected_idle = pick(selected_idle, "selected_idle", idle)
@@ -1195,6 +1205,7 @@ def _imagemap(ground=None, hover=None, insensitive=None, idle=None, selected_hov
 
 imagemap = Wrapper(_imagemap, imagemap=True, style='imagemap')
 
+
 def _hotspot(spot, style='hotspot', **properties):
 
     if not imagemap_stack:
@@ -1247,11 +1258,13 @@ def _hotspot(spot, style='hotspot', **properties):
 
 hotspot_with_child = Wrapper(_hotspot, style="hotspot", one=True)
 
+
 def hotspot(*args, **kwargs):
     hotspot_with_child(*args, **kwargs)
     null()
 
-def _hotbar(spot, adjustment=None, range=None, value=None, **properties): #@ReservedAssignment
+
+def _hotbar(spot, adjustment=None, range=None, value=None, **properties):  # @ReservedAssignment
 
     if (adjustment is None) and (range is None) and (value is None):
         raise Exception("hotbar requires either an adjustment or a range and value.")
@@ -1281,22 +1294,22 @@ def _hotbar(spot, adjustment=None, range=None, value=None, **properties): #@Rese
         hover_fore_bar, hover_aft_bar = hover_aft_bar, hover_fore_bar
 
     return renpy.display.behavior.Bar(
-            adjustment=adjustment,
-            range=range,
-            value=value,
-            fore_bar=fore_bar,
-            aft_bar=aft_bar,
-            hover_fore_bar=hover_fore_bar,
-            hover_aft_bar=hover_aft_bar,
-            fore_gutter=0,
-            aft_gutter=0,
-            bar_resizing=False,
-            thumb=None,
-            thumb_shadow=None,
-            thumb_offset=0,
-            xmaximum=w,
-            ymaximum=h,
-            **properties)
+        adjustment=adjustment,
+        range=range,
+        value=value,
+        fore_bar=fore_bar,
+        aft_bar=aft_bar,
+        hover_fore_bar=hover_fore_bar,
+        hover_aft_bar=hover_aft_bar,
+        fore_gutter=0,
+        aft_gutter=0,
+        bar_resizing=False,
+        thumb=None,
+        thumb_shadow=None,
+        thumb_offset=0,
+        xmaximum=w,
+        ymaximum=h,
+        **properties)
 
 hotbar = Wrapper(_hotbar, style="hotbar", replaces=True)
 
@@ -1310,6 +1323,7 @@ def _returns(v):
 
 returns = renpy.curry.curry(_returns)
 
+
 def _jumps(label, transition=None):
 
     if isinstance(transition, basestring):
@@ -1322,20 +1336,28 @@ def _jumps(label, transition=None):
 
 jumps = renpy.curry.curry(_jumps)
 
+
 def _jumpsoutofcontext(label):
 
     raise renpy.game.JumpOutException(label)
 
 jumpsoutofcontext = renpy.curry.curry(_jumpsoutofcontext)
 
+
 def callsinnewcontext(*args, **kwargs):
     return renpy.exports.curried_call_in_new_context(*args, **kwargs)
 
+
 def invokesinnewcontext(*args, **kwargs):
     return renpy.exports.curried_invoke_in_new_context(*args, **kwargs)
 
+
 def gamemenus(*args):
-    return callsinnewcontext("_game_menu", *args)
+
+    if args:
+        return callsinnewcontext("_game_menu", _game_menu_screen=args[0])
+    else:
+        return callsinnewcontext("_game_menu")
 
 ##############################################################################
 # The on statement.
@@ -1344,6 +1366,8 @@ on = Wrapper(renpy.display.behavior.OnEvent)
 
 ##############################################################################
 # A utility function so CDD components can be given an id.
+
+
 def screen_id(id_, d):
     """
     :doc: ui
